[JAUNTY] SRU: UBUNTU: SAUCE: Added quirk to fix key release for Samsung NC20

Manoj Iyer manoj.iyer at canonical.com
Wed Apr 22 20:53:14 UTC 2009


SRU justification:

IMPACT: Samsung nc20 brightness keys do not send release events
FIX: patch similar to the one done for NC10 laptops, use dmi_match to call 
atkbd_samsung_keymap_fixup for NC20.
TEST: A test kernel from http://people.ubuntu.com/~manjo/lp360247-jaunty/ 
was tested by the originator of the bug, and verified to fix this problem.

The following changes since commit 
a63b7d7beeaa1f8f33369cab6419831fa8991e40:
   Tyler Hicks (1):
         UBUNTU: SAUCE: (drop after 2.6.28) [PATCH] eCryptfs: Larger buffer 
for encrypted symlink targets

are available in the git repository at:

   git://kernel.ubuntu.com/manjo/ubuntu-jaunty.git lp360247

Manoj Iyer (1):
       UBUNTU: SAUCE: Added quirk to fix key release for Samsung NC20

  drivers/input/keyboard/atkbd.c |   11 ++++++++++-
  1 files changed, 10 insertions(+), 1 deletions(-)



>From 7b4861c34d7555217a36dff8598e29148baf6a4b Mon Sep 17 00:00:00 2001
From: Manoj Iyer <manoj.iyer at canonical.com>
Date: Tue, 21 Apr 2009 23:04:47 -0500
Subject: [PATCH] UBUNTU: SAUCE: Added quirk to fix key release for Samsung NC20

OriginalAuthor: Barry Carroll <x00021665 at itnet.ie>
Bug: #360247

Signed-off-by: Manoj Iyer <manoj.iyer at canonical.com>
---
  drivers/input/keyboard/atkbd.c |   11 ++++++++++-
  1 files changed, 10 insertions(+), 1 deletions(-)

diff --git a/drivers/input/keyboard/atkbd.c b/drivers/input/keyboard/atkbd.c
index 443bee5..4a4eb12 100644
--- a/drivers/input/keyboard/atkbd.c
+++ b/drivers/input/keyboard/atkbd.c
@@ -901,7 +901,7 @@ static void atkbd_hp_zv6100_keymap_fixup(struct atkbd *atkbd)
  }

  /*
  * Samsung NC10 with Fn+F? key release not working
   */
  static void atkbd_samsung_keymap_fixup(struct atkbd *atkbd)
  {
@@ -1570,6 +1570,15 @@ static struct dmi_system_id atkbd_dmi_quirk_table[] __initdata = {
  		.driver_data = atkbd_samsung_keymap_fixup,
  	},
  	{
+		.ident = "Samsung NC20",
+		.matches = {
+			DMI_MATCH(DMI_SYS_VENDOR, "SAMSUNG ELECTRONICS CO., LTD."),
+			DMI_MATCH(DMI_PRODUCT_NAME, "NC20"),
+		},
+		.callback = atkbd_setup_fixup,
+		.driver_data = atkbd_samsung_keymap_fixup,
+	},
+	{
  		.ident = "Znote 6615WD",
  		.matches = {
  			DMI_MATCH(DMI_SYS_VENDOR, "Zepto"),
@@ -901,7 +901,7 @@ static void atkbd_hp_zv6100_keymap_fixup(struct atkbd *atkbd)

  /*
- * Samsung NC10 with Fn+F? key release not working
+ * Samsung NC10, NC20 with Fn+F? key release not working
   */
  static void atkbd_samsung_keymap_fixup(struct atkbd *atkbd)
-- 
1.6.0.4


Cheers
--- manjo




More information about the kernel-team mailing list